<?xml version="1.0" encoding="shift_jis"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" > 
<xsl:import href="./common.xsl"/>
<xsl:output method="html" doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" />

<!-- ****** TOP ****** -->
<xsl:template match="/">
	<xsl:apply-templates select="dynamic_document">
		<xsl:with-param name="select_type" select="'2'"/>
		<xsl:with-param name="data_type" select="$TARGET_DAT_TABLE"/>
		<xsl:with-param name="id" select="$HEADER_ID"/>
	</xsl:apply-templates>
</xsl:template>

<xsl:template match="header">
	<xsl:call-template name="title_tab">
		<xsl:with-param name="name" select="concat($TABLE,$DETAIL)"/>
		<xsl:with-param name="image" select="$IMG_TABLE"/>
	</xsl:call-template>
	
<xsl:element name="table">
	<xsl:attribute name="class">main</xsl:attribute>

	<xsl:element name="tr">
		<xsl:attribute name="style">width:100%</xsl:attribute>
		<xsl:element name="th">
			<xsl:attribute name="style">width:30%</xsl:attribute><xsl:value-of select="$LOGICAL_NAME" />
		</xsl:element>
		<xsl:element name="td"><xsl:value-of select="logical_name" /></xsl:element>
	</xsl:element>

	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$PHYSICAL_NAME" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="physical_name" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$CONNECTION_DB" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="connection_db" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$COMMENT" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="memo" /></xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$CREATE_USER" /> (<xsl:value-of select="$CREATE_DATE" />)</xsl:element>
		<xsl:element name="td"><xsl:value-of select="create_user" /> ( <xsl:call-template name="formatdate"><xsl:with-param name="word" select="create_date"/></xsl:call-template> )</xsl:element>
	</xsl:element>
	<xsl:element name="tr">
		<xsl:element name="th"><xsl:value-of select="$UPDATE_USER" /> (<xsl:value-of select="$UPDATE_DATE" />)</xsl:element>
		<xsl:element name="td"><xsl:value-of select="update_user" /> ( <xsl:call-template name="formatdate"><xsl:with-param name="word" select="update_date"/></xsl:call-template> )</xsl:element>
	</xsl:element>
</xsl:element>
<xsl:element name="br" />

</xsl:template>

<!-- ****** Detail ****** -->
<xsl:template match="detail">
	<!-- table -->
	<xsl:if test="$HREF = 'data'">
		<xsl:call-template name="table_records"/>
	</xsl:if>
	<!-- dc -->
	<xsl:if test="$HREF = 'dc'">
		<xsl:call-template name="dcs"/>
	</xsl:if>
	<!-- ssub -->
	<xsl:if test="$HREF = 'samc'">
		<xsl:call-template name="ssubs"/>
	</xsl:if>
	<!-- client -->
	<xsl:if test="$HREF = 'client'">
		<xsl:call-template name="frames"/>
	</xsl:if>
	<!-- bsub -->
	<xsl:if test="$HREF = 'smc'">
		<xsl:call-template name="smcs"/>
	</xsl:if>
</xsl:template>


<!-- ****** TableRecords ****** -->
<xsl:template name="table_records">
<xsl:element name="br" />
<xsl:element name="table">
	<xsl:attribute name="class">main</xsl:attribute>
	<xsl:attribute name="summary">Table</xsl:attribute>

	<xsl:element name="tr">
		<xsl:attribute name="style">width:100%</xsl:attribute>
		<xsl:element name="th">
			<xsl:attribute name="style">width:20;text-align:right;</xsl:attribute>
			<xsl:element name="th">
				<xsl:attribute name="class">LOGICAL_NAME</xsl:attribute><xsl:value-of select="$LOGICAL_NAME" />
			</xsl:element>
			<xsl:element name="th">
				<xsl:attribute name="class">PHYSICAL_NAME</xsl:attribute><xsl:value-of select="$PHYSICAL_NAME" />
			</xsl:element>
			<xsl:element name="th">
				<xsl:attribute name="class">TYPE</xsl:attribute><xsl:value-of select="$TYPE" />
			</xsl:element>
			<xsl:element name="th">
				<xsl:attribute name="class">LENGTH</xsl:attribute><xsl:value-of select="$LENGTH" />
			</xsl:element>
			<xsl:element name="th">
				<xsl:attribute name="class">SCALE</xsl:attribute><xsl:value-of select="$SCALE" />
			</xsl:element>
			<xsl:element name="th">
				<xsl:attribute name="class">MEMO</xsl:attribute><xsl:value-of select="$COMMENT" />
			</xsl:element>
		</xsl:element>
	</xsl:element>
	
	<xsl:for-each select="record">
	<xsl:element name="tr">
		<xsl:element name="td">
			<xsl:attribute name="style">text-align:right;</xsl:attribute><xsl:number level="single" format="1" count="record" />
		</xsl:element>
		<xsl:element name="td">
			<xsl:attribute name="class">LOGICAL_NAME</xsl:attribute>
			<xsl:element name="a">
				<xsl:attribute name="href">
					<xsl:call-template name="create_link">
						<xsl:with-param name="data_type" select="$TARGET_DAT_DATA"/>
						<xsl:with-param name="select_type" select="3"/>
						<xsl:with-param name="id" select="./id"/>
					</xsl:call-template>
				</xsl:attribute>
				<xsl:value-of select="logical_name" />
			</xsl:element>
		</xsl:element>
		<xsl:element name="td">
			<xsl:attribute name="class">PHYSICAL_NAME</xsl:attribute><xsl:value-of select="physical_name" />
		</xsl:element>
		<xsl:element name="td">
			<xsl:attribute name="class">TYPE</xsl:attribute><xsl:value-of select="type" />
		</xsl:element>
		<xsl:element name="td">
			<xsl:attribute name="class">LENGTH</xsl:attribute><xsl:value-of select="length" />
		</xsl:element>
		<xsl:element name="td">
			<xsl:attribute name="class">SCALE</xsl:attribute><xsl:value-of select="scale" />
		</xsl:element>
		<xsl:element name="td">
			<xsl:attribute name="MEMO">SCALE</xsl:attribute><xsl:value-of select="memo" />
		</xsl:element>
	</xsl:element>
	</xsl:for-each>
</xsl:element>
</xsl:template>

<xsl:template match="pkey">
<xsl:element name="div">
<xsl:element name="table">
	<xsl:attribute name="summary">PRIMARY KEY INFORMATION</xsl:attribute>
	<xsl:element name="caption">PRIMARY KEY INFORMATION</xsl:element>
	<xsl:element name="tr">
		<xsl:attribute name="style">width:100%</xsl:attribute>
		<xsl:element name="th"><xsl:value-of select="$LOGICAL_NAME" /></xsl:element>
		<xsl:element name="th"><xsl:value-of select="$PHYSICAL_NAME" /></xsl:element>
		<xsl:element name="th"><xsl:value-of select="$COMMENT" /></xsl:element>
	</xsl:element>
	<xsl:for-each select="field">
	<xsl:element name="tr">
		<xsl:element name="td"><xsl:value-of select="logical_name" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="physical_name" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="memo" /></xsl:element>
	</xsl:element>
	</xsl:for-each>
</xsl:element>
</xsl:element>
</xsl:template>

<xsl:template match="fkey">
<xsl:element name="div">
<xsl:element name="table">
	<xsl:attribute name="summary">FOREIGN KEY INFORMATION</xsl:attribute>
	<xsl:element name="caption">FOREIGN KEY INFORMATION</xsl:element>
	<xsl:element name="tr">
		<xsl:attribute name="style">width:100%</xsl:attribute>
		<xsl:element name="th"><xsl:value-of select="$LOGICAL_NAME" /></xsl:element>
		<xsl:element name="th"><xsl:value-of select="$PHYSICAL_NAME" /></xsl:element>
		<xsl:element name="th"><xsl:value-of select="$COMMENT" /></xsl:element>
	</xsl:element>

	<xsl:for-each select="field">
	<xsl:element name="tr">
		<xsl:element name="td"><xsl:value-of select="logical_name" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="physical_name" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="memo" /></xsl:element>
	</xsl:element>
	</xsl:for-each>
</xsl:element>
</xsl:element>
</xsl:template>

<xsl:template match="ikey">
<xsl:element name="div">
<xsl:element name="table">
	<xsl:attribute name="summary">INDEX KEY INFORMATION</xsl:attribute>
	<xsl:element name="caption">INDEX KEY INFORMATION</xsl:element>

	<xsl:element name="tr">
		<xsl:attribute name="style">width:100%</xsl:attribute>
		<xsl:element name="th"><xsl:value-of select="$LOGICAL_NAME" /></xsl:element>
		<xsl:element name="th"><xsl:value-of select="$PHYSICAL_NAME" /></xsl:element>
		<xsl:element name="th"><xsl:value-of select="$COMMENT" /></xsl:element>
	</xsl:element>

	<xsl:for-each select="field">
	<xsl:element name="tr">
		<xsl:element name="td"><xsl:value-of select="logical_name" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="physical_name" /></xsl:element>
		<xsl:element name="td"><xsl:value-of select="memo" /></xsl:element>
	</xsl:element>
	</xsl:for-each>
	</xsl:element>
</xsl:element>

</xsl:template>
</xsl:stylesheet>
